@@ -2,12 +2,15 @@ use strict;
 use warnings;
 
 package Git::Helpers;
-$Git::Helpers::VERSION = '0.000006';
+$Git::Helpers::VERSION = '0.000007';
 use Carp qw( croak );
 use File::pushd qw( pushd );
 use Git::Sub;
-use Sub::Exporter -setup => { exports =>
-        [ 'checkout_root', 'https_remote_url', 'remote_url', 'travis_url', ]
+use Sub::Exporter -setup => {
+    exports => [
+        'checkout_root', 'current_branch_name', 'https_remote_url',
+        'remote_url',    'travis_url',
+    ]
 };
 use Try::Tiny qw( catch try );
 use URI ();
@@ -32,8 +35,15 @@ sub checkout_root {
     return $root;
 }
 
+# Works as of 1.6.3:1
+# http://stackoverflow.com/questions/1417957/show-just-the-current-branch-in-git
+sub current_branch_name {
+    return git::rev_parse( '--abbrev-ref', 'HEAD' );
+}
+
 sub https_remote_url {
     my $remote_url = remote_url(shift);
+    my $branch     = shift;
 
     # remove trailing .git
     $remote_url =~ s{\.git\z}{};
@@ -44,6 +54,10 @@ sub https_remote_url {
     # remove : from git@github.com:username/repo.git
     $remote_url =~ s{(\w):(\w)}{$1/$2};
 
+    if ($branch) {
+        $remote_url .= '/tree/' . current_branch_name();
+    }
+
     my $uri = URI->new( uf_uristr($remote_url) );
     $uri->scheme('https');
     return $uri;
@@ -80,7 +94,7 @@ Git::Helpers - Shortcuts for common Git commands
 
 =head1 VERSION
 
-version 0.000006
+version 0.000007
 
 =head1 SYNOPSIS
 
@@ -101,7 +115,11 @@ find the top level of the repository.
 This method will throw an exception if it cannot find a git repository at the
 directory provided.
 
-=head2 https_remote_url( $remote_name )
+=head2 current_branch_name
+
+Returns the name of the current branch.
+
+=head2 https_remote_url( $remote_name, $use_current_branch )
 
 This is a browser-friendly URL for the remote, fixed up in such a way that
 GitHub (hopefully) doesn't need to redirect your URL.
@@ -112,9 +130,13 @@ Turns https://github.com/oalders/git-helpers.git into https://github.com/oalders
 
 Defaults to using C<origin> as the remote if none is supplied.
 
+Defaults to master branch, but can also display current branch.
+
+    my $current_branch_url = https_remote_url( 'origin', 1 );
+
 =head2 remote_url( $remote_name )
 
-Returns a URL for the upstream you've requested by name.  Defaults to 'origin'.
+Returns a URL for the remote you've requested by name.  Defaults to 'origin'.
 Provides you with the exact URL which git returns. Nothing is fixed up for you.
 
     # defaults to 'origin'
@@ -124,11 +146,12 @@ Provides you with the exact URL which git returns. Nothing is fixed up for you.
     # https://github.com/oalders/git-helpers.git
 
     # get URL for upstream remote
-    my $remote_url = remote_url('upstream');
+    my $upstream_url = remote_url('upstream');
 
 =head2 travis_url( $remote_name )
 
-Returns a L<travis-ci.org> URL for the upstream you've requested by name.  Defaults to 'origin'.
+Returns a L<travis-ci.org> URL for the remote you've requested by name.
+Defaults to 'origin'.
 
     # get Travis URL for remote named "origin"
     my $origin_travis_url = travis_url();
